--
-- Mod: FS22_RealLifeNumbers by Kaj-Aage Henneberg "Ki", ArmChairFarming
-- Script: RealNumbersStorePrices by Kaj-Aage Henneberg "Ki", ArmChairFarming
-- e-mail: kaj-aage.henneberg@outlook.dk
-- Download: www.modhoster.com
-- All rights reserved.
-- Version 1.0.0.4
-- 26-11-2021

RealNumbersStorePrices = {};

function RealNumbersStorePrices:loadMap(name)

	RN.storePriceScaling = {};
	RN.storePriceScaling.bales 			= 0.1;			-- default RLN value = 0.1; vanilla game = 1
	RN.storePriceScaling.bigbags 		= 0.1;			-- default RLN value = 0.1; vanilla game = 1
	RN.storePriceScaling.bigbagpallets 	= 0.1;			-- default RLN value = 0.1; vanilla game = 1
	RN.storePriceScaling.pallets 		= 0.1;			-- default RLN value = 0.1; vanilla game = 1
	RN.notRunYetRealNumbersStorePrices 	= true;
	RN.upStartRealNumbersStorePrices 	= true;

	RN.dailyUpKeepScalingIsActive		= true;			-- set to false dailyUpKeep should not be scaled

	if g_currentMission.environment.daysPerPeriod ~= nil then
		RN.gameDaysPerYear = g_currentMission.environment.daysPerPeriod * 12;
	else
		RN.gameDaysPerYear = 36;
	end;
	
	RN.placeableCategories = {"ANIMALPENS","BALES","BEEHIVES","BIGBAGPALLETS","BIGBAGS","DIESELTANKS",
								"FARMHOUSES","FENCES","FILLABLETANKS","FLOODLIGHTING","GARDENSHEDS",
								"GENERATORS","PALLETS","PLACEABLEMISC","PRODUCTIONPOINTS","SELLINGPOINTS",
								"SHEDS","SILOS","SILOEXTENSIONS","STORAGES","TREES","WATERTANKS"};

	RN.dailyUpkeep = {}; -- scaling factors for different categories of items.
	
	-- Daily upkeep covers daily maintenance (e.g. greasing, not repair), tax and insurance
	-- Fuel and vehicle repair is not included in daily upkeep
	-- Scaling factor is multipled by retail price to obtain actual dailyUpkeep
	-- Scaling factor is = 0.01 * percentage of retail price / gamedays per year
	-- Example: item price = 100,000 eu
	-- Maintenance cost per year: 0.5% = 500 eu
	-- Tax cost per year		: 0.1% = 100 eu
	-- Insurance cost per year  : 0.1% = 100 eu
	-- Total MTI cost per year  : 0.7% = 700 eu 
	-- 
	-- Change as you see fit. The values defined here are guesses.
	
	RN.dailyUpkeep["motorizedVehicle"] 	= 0.7	/(100*RN.gameDaysPerYear);		-- Maintenance, tax and insurance
	RN.dailyUpkeep["implement"]			= 0.2	/(100*RN.gameDaysPerYear);		-- Maintenance
	RN.dailyUpkeep["handTool"] 			= 0.2	/(100*RN.gameDaysPerYear);		-- Maintenance
	RN.dailyUpkeep["ANIMALPENS"] 		= 0.5	/(100*RN.gameDaysPerYear);		-- Maintenance
	RN.dailyUpkeep["BALES"] 			= 0.01	/(100*RN.gameDaysPerYear);		-- Maintenance
	RN.dailyUpkeep["BEEHIVES"] 			= 0.2	/(100*RN.gameDaysPerYear);		-- Maintenance
	RN.dailyUpkeep["BIGBAGPALLETS"] 	= 0.01	/(100*RN.gameDaysPerYear);		-- Maintenance
	RN.dailyUpkeep["BIGBAGS"] 			= 0.01	/(100*RN.gameDaysPerYear);		-- Maintenance
	RN.dailyUpkeep["DIESELTANKS"] 		= 0.05	/(100*RN.gameDaysPerYear);		-- Maintenance
	RN.dailyUpkeep["FARMHOUSES"] 		= 0.5	/(100*RN.gameDaysPerYear);		-- Maintenance
	RN.dailyUpkeep["FENCES"] 			= 0.05	/(100*RN.gameDaysPerYear);		-- Maintenance
	RN.dailyUpkeep["FILLABLETANKS"] 	= 0.05	/(100*RN.gameDaysPerYear);		-- Maintenance
	RN.dailyUpkeep["FLOODLIGHTING"] 	= 0.2	/(100*RN.gameDaysPerYear);		-- Maintenance
	RN.dailyUpkeep["GARDENSHEDS"] 		= 0.1	/(100*RN.gameDaysPerYear);		-- Maintenance
	RN.dailyUpkeep["GENERATORS"] 		= 0.2	/(100*RN.gameDaysPerYear);		-- Maintenance
	RN.dailyUpkeep["PALLETS"] 			= 0.01	/(100*RN.gameDaysPerYear);		-- Maintenance
	RN.dailyUpkeep["PLACEABLEMISC"] 	= 0.1	/(100*RN.gameDaysPerYear);		-- Maintenance
	RN.dailyUpkeep["PRODUCTIONPOINTS"] 	= 0.5	/(100*RN.gameDaysPerYear);		-- Maintenance
	RN.dailyUpkeep["SELLINGPOINTS"] 	= 0.2	/(100*RN.gameDaysPerYear);		-- Maintenance
	RN.dailyUpkeep["SHEDS"] 			= 0.2	/(100*RN.gameDaysPerYear);		-- Maintenance
	RN.dailyUpkeep["SILOS"] 			= 0.2	/(100*RN.gameDaysPerYear);		-- Maintenance
	RN.dailyUpkeep["SILOEXTENSIONS"] 	= 0.2	/(100*RN.gameDaysPerYear);		-- Maintenance
	RN.dailyUpkeep["STORAGES"] 			= 0.2	/(100*RN.gameDaysPerYear);		-- Maintenance
	RN.dailyUpkeep["TREES"] 			= 0.01	/(100*RN.gameDaysPerYear);		-- Maintenance	
	RN.dailyUpkeep["WATERTANKS"] 		= 0.01	/(100*RN.gameDaysPerYear);		-- Maintenance		

	print("\n --- RealNumbersStorePrices.lua started --- \n");

	for i, v in pairs(g_storeManager.items) do


		if g_storeManager.items[i].price   ~= nil then
			if g_storeManager.items[i].categoryName == "BALES" then
				g_storeManager.items[i].price   = g_storeManager.items[i].price * RN.storePriceScaling.bales;
				for n = 1,8 do
					g_storeManager.items[i].configurations.multipleItemPurchaseAmount[n].price = (n-1) * g_storeManager.items[i].price;
				end;
			end;
			if g_storeManager.items[i].categoryName == "BIGBAGS" then
				g_storeManager.items[i].price   = g_storeManager.items[i].price * RN.storePriceScaling.bigbags;
			end;
			if g_storeManager.items[i].categoryName == "BIGBAGPALLETS" then
				g_storeManager.items[i].price   = g_storeManager.items[i].price * RN.storePriceScaling.bigbagpallets;
			end;
			if g_storeManager.items[i].categoryName == "PALLETS" then
				g_storeManager.items[i].price   = g_storeManager.items[i].price * RN.storePriceScaling.pallets;
			end;
		end;		
	end;
	print("\n --- RealNumbersStorePrices.lua finished --- \n");
end;


function RealNumbersStorePrices:keyEvent(unicode, sym, modifier, isDown)
end;

function RealNumbersStorePrices:update(dt)
	if runMinute ~= 8 then RN.notRunYetRealNumbersStorePrices = true; end;
	if runMinute == 8 or RN.upStartRealNumbersStorePrices then
		if RN.notRunYetRealNumbersStorePrices then
			for i, v in pairs(g_storeManager.items) do
				if g_storeManager.items[i].categoryName == "BIGBAGS" then
					if g_storeManager.items[i].configurations.multipleItemPurchaseAmount ~= nil then
						for n = 1,8 do
							g_storeManager.items[i].configurations.multipleItemPurchaseAmount[n].price = (n-1) * g_storeManager.items[i].price;
						end;
					end;
				end;
				if g_storeManager.items[i].categoryName == "BIGBAGPALLETS" then
					if g_storeManager.items[i].configurations.multipleItemPurchaseAmount ~= nil then
						for n = 1,8 do
							g_storeManager.items[i].configurations.multipleItemPurchaseAmount[n].price = (n-1) * g_storeManager.items[i].price;
						end;
					end;
				end;	

	-- Define dailyUpkeep
				
				if RN.dailyUpKeepScalingIsActive then
					if g_storeManager.items[i].dailyUpkeep    ~= nil then
						if g_storeManager.items[i].species == "vehicle" then
							g_storeManager.items[i].dailyUpkeep = RN.dailyUpkeep["implement"] * g_storeManager.items[i].price;
							if g_storeManager.items[i].hasLicensePlates then
								g_storeManager.items[i].dailyUpkeep = RN.dailyUpkeep["motorizedVehicle"] * g_storeManager.items[i].price;				
							end;					
						elseif g_storeManager.items[i].species == "handTool" then
							g_storeManager.items[i].dailyUpkeep = RN.dailyUpkeep["handTool"] * g_storeManager.items[i].price;					
						elseif g_storeManager.items[i].species == "placeable" then
							for k = 1,#RN.placeableCategories do
								local category = RN.placeableCategories[k];
								if g_storeManager.items[i].categoryName == category then
	--								print(category);	-- debug
									g_storeManager.items[i].dailyUpkeep = RN.dailyUpkeep[category] * g_storeManager.items[i].price;								
								end;
							end;					
						end;				
					end;
				end;
			end;
			RN.notRunYetRealNumbersStorePrices = false;
			RN.upStartRealNumbersStorePrices = false;
		end;
	end;
end;
function RealNumbersStorePrices:draw()
end;
function RealNumbersStorePrices:deleteMap()
end;
function RealNumbersStorePrices:mouseEvent(posX, posY, isDown, isUp, button)
end;

addModEventListener(RealNumbersStorePrices);







